@@ -2,3 +2,6 @@
 
 mod eeprom;
 pub use eeprom::*;
+
+#[cfg(test)]
+mod test;
